# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class SmsPreview(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'body': 'str',
        'phone_number': 'str',
        'from_number': 'str',
        'read': 'bool',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'body': 'body',
        'phone_number': 'phoneNumber',
        'from_number': 'fromNumber',
        'read': 'read',
        'created_at': 'createdAt'
    }

    def __init__(self, id=None, user_id=None, body=None, phone_number=None, from_number=None, read=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """SmsPreview - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._body = None
        self._phone_number = None
        self._from_number = None
        self._read = None
        self._created_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.body = body
        self.phone_number = phone_number
        self.from_number = from_number
        self.read = read
        self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this SmsPreview.  # noqa: E501


        :return: The id of this SmsPreview.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SmsPreview.


        :param id: The id of this SmsPreview.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this SmsPreview.  # noqa: E501


        :return: The user_id of this SmsPreview.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this SmsPreview.


        :param user_id: The user_id of this SmsPreview.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def body(self):
        """Gets the body of this SmsPreview.  # noqa: E501


        :return: The body of this SmsPreview.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this SmsPreview.


        :param body: The body of this SmsPreview.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and body is None:  # noqa: E501
            raise ValueError("Invalid value for `body`, must not be `None`")  # noqa: E501

        self._body = body

    @property
    def phone_number(self):
        """Gets the phone_number of this SmsPreview.  # noqa: E501


        :return: The phone_number of this SmsPreview.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this SmsPreview.


        :param phone_number: The phone_number of this SmsPreview.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def from_number(self):
        """Gets the from_number of this SmsPreview.  # noqa: E501


        :return: The from_number of this SmsPreview.  # noqa: E501
        :rtype: str
        """
        return self._from_number

    @from_number.setter
    def from_number(self, from_number):
        """Sets the from_number of this SmsPreview.


        :param from_number: The from_number of this SmsPreview.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and from_number is None:  # noqa: E501
            raise ValueError("Invalid value for `from_number`, must not be `None`")  # noqa: E501

        self._from_number = from_number

    @property
    def read(self):
        """Gets the read of this SmsPreview.  # noqa: E501


        :return: The read of this SmsPreview.  # noqa: E501
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """Sets the read of this SmsPreview.


        :param read: The read of this SmsPreview.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and read is None:  # noqa: E501
            raise ValueError("Invalid value for `read`, must not be `None`")  # noqa: E501

        self._read = read

    @property
    def created_at(self):
        """Gets the created_at of this SmsPreview.  # noqa: E501


        :return: The created_at of this SmsPreview.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SmsPreview.


        :param created_at: The created_at of this SmsPreview.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmsPreview):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SmsPreview):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ReputationItemProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_at': 'datetime',
        'recipient': 'str',
        'reputation_type': 'str',
        'id': 'str',
        'severity': 'str',
        'source': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'recipient': 'recipient',
        'reputation_type': 'reputationType',
        'id': 'id',
        'severity': 'severity',
        'source': 'source'
    }

    def __init__(self, created_at=None, recipient=None, reputation_type=None, id=None, severity=None, source=None, local_vars_configuration=None):  # noqa: E501
        """ReputationItemProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._recipient = None
        self._reputation_type = None
        self._id = None
        self._severity = None
        self._source = None
        self.discriminator = None

        self.created_at = created_at
        if recipient is not None:
            self.recipient = recipient
        self.reputation_type = reputation_type
        self.id = id
        self.severity = severity
        if source is not None:
            self.source = source

    @property
    def created_at(self):
        """Gets the created_at of this ReputationItemProjection.  # noqa: E501


        :return: The created_at of this ReputationItemProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ReputationItemProjection.


        :param created_at: The created_at of this ReputationItemProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def recipient(self):
        """Gets the recipient of this ReputationItemProjection.  # noqa: E501


        :return: The recipient of this ReputationItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this ReputationItemProjection.


        :param recipient: The recipient of this ReputationItemProjection.  # noqa: E501
        :type: str
        """

        self._recipient = recipient

    @property
    def reputation_type(self):
        """Gets the reputation_type of this ReputationItemProjection.  # noqa: E501


        :return: The reputation_type of this ReputationItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._reputation_type

    @reputation_type.setter
    def reputation_type(self, reputation_type):
        """Sets the reputation_type of this ReputationItemProjection.


        :param reputation_type: The reputation_type of this ReputationItemProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and reputation_type is None:  # noqa: E501
            raise ValueError("Invalid value for `reputation_type`, must not be `None`")  # noqa: E501
        allowed_values = ["COMPLAINT", "BOUNCE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and reputation_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `reputation_type` ({0}), must be one of {1}"  # noqa: E501
                .format(reputation_type, allowed_values)
            )

        self._reputation_type = reputation_type

    @property
    def id(self):
        """Gets the id of this ReputationItemProjection.  # noqa: E501


        :return: The id of this ReputationItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ReputationItemProjection.


        :param id: The id of this ReputationItemProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def severity(self):
        """Gets the severity of this ReputationItemProjection.  # noqa: E501


        :return: The severity of this ReputationItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this ReputationItemProjection.


        :param severity: The severity of this ReputationItemProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and severity is None:  # noqa: E501
            raise ValueError("Invalid value for `severity`, must not be `None`")  # noqa: E501
        allowed_values = ["INFO", "WARNING", "DANGER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and severity not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `severity` ({0}), must be one of {1}"  # noqa: E501
                .format(severity, allowed_values)
            )

        self._severity = severity

    @property
    def source(self):
        """Gets the source of this ReputationItemProjection.  # noqa: E501


        :return: The source of this ReputationItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this ReputationItemProjection.


        :param source: The source of this ReputationItemProjection.  # noqa: E501
        :type: str
        """

        self._source = source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReputationItemProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ReputationItemProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class LookupMtaStsDomainResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'valid': 'bool',
        'query': 'DNSLookupOptions',
        'records': 'list[DNSLookupResult]',
        'well_known_query': 'str',
        'well_known_present': 'bool',
        'well_known_value': 'str',
        'errors': 'list[str]',
        'warnings': 'list[str]'
    }

    attribute_map = {
        'valid': 'valid',
        'query': 'query',
        'records': 'records',
        'well_known_query': 'wellKnownQuery',
        'well_known_present': 'wellKnownPresent',
        'well_known_value': 'wellKnownValue',
        'errors': 'errors',
        'warnings': 'warnings'
    }

    def __init__(self, valid=None, query=None, records=None, well_known_query=None, well_known_present=None, well_known_value=None, errors=None, warnings=None, local_vars_configuration=None):  # noqa: E501
        """LookupMtaStsDomainResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._valid = None
        self._query = None
        self._records = None
        self._well_known_query = None
        self._well_known_present = None
        self._well_known_value = None
        self._errors = None
        self._warnings = None
        self.discriminator = None

        self.valid = valid
        self.query = query
        self.records = records
        self.well_known_query = well_known_query
        self.well_known_present = well_known_present
        self.well_known_value = well_known_value
        self.errors = errors
        self.warnings = warnings

    @property
    def valid(self):
        """Gets the valid of this LookupMtaStsDomainResults.  # noqa: E501


        :return: The valid of this LookupMtaStsDomainResults.  # noqa: E501
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """Sets the valid of this LookupMtaStsDomainResults.


        :param valid: The valid of this LookupMtaStsDomainResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and valid is None:  # noqa: E501
            raise ValueError("Invalid value for `valid`, must not be `None`")  # noqa: E501

        self._valid = valid

    @property
    def query(self):
        """Gets the query of this LookupMtaStsDomainResults.  # noqa: E501


        :return: The query of this LookupMtaStsDomainResults.  # noqa: E501
        :rtype: DNSLookupOptions
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this LookupMtaStsDomainResults.


        :param query: The query of this LookupMtaStsDomainResults.  # noqa: E501
        :type: DNSLookupOptions
        """
        if self.local_vars_configuration.client_side_validation and query is None:  # noqa: E501
            raise ValueError("Invalid value for `query`, must not be `None`")  # noqa: E501

        self._query = query

    @property
    def records(self):
        """Gets the records of this LookupMtaStsDomainResults.  # noqa: E501


        :return: The records of this LookupMtaStsDomainResults.  # noqa: E501
        :rtype: list[DNSLookupResult]
        """
        return self._records

    @records.setter
    def records(self, records):
        """Sets the records of this LookupMtaStsDomainResults.


        :param records: The records of this LookupMtaStsDomainResults.  # noqa: E501
        :type: list[DNSLookupResult]
        """
        if self.local_vars_configuration.client_side_validation and records is None:  # noqa: E501
            raise ValueError("Invalid value for `records`, must not be `None`")  # noqa: E501

        self._records = records

    @property
    def well_known_query(self):
        """Gets the well_known_query of this LookupMtaStsDomainResults.  # noqa: E501


        :return: The well_known_query of this LookupMtaStsDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._well_known_query

    @well_known_query.setter
    def well_known_query(self, well_known_query):
        """Sets the well_known_query of this LookupMtaStsDomainResults.


        :param well_known_query: The well_known_query of this LookupMtaStsDomainResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and well_known_query is None:  # noqa: E501
            raise ValueError("Invalid value for `well_known_query`, must not be `None`")  # noqa: E501

        self._well_known_query = well_known_query

    @property
    def well_known_present(self):
        """Gets the well_known_present of this LookupMtaStsDomainResults.  # noqa: E501


        :return: The well_known_present of this LookupMtaStsDomainResults.  # noqa: E501
        :rtype: bool
        """
        return self._well_known_present

    @well_known_present.setter
    def well_known_present(self, well_known_present):
        """Sets the well_known_present of this LookupMtaStsDomainResults.


        :param well_known_present: The well_known_present of this LookupMtaStsDomainResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and well_known_present is None:  # noqa: E501
            raise ValueError("Invalid value for `well_known_present`, must not be `None`")  # noqa: E501

        self._well_known_present = well_known_present

    @property
    def well_known_value(self):
        """Gets the well_known_value of this LookupMtaStsDomainResults.  # noqa: E501


        :return: The well_known_value of this LookupMtaStsDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._well_known_value

    @well_known_value.setter
    def well_known_value(self, well_known_value):
        """Sets the well_known_value of this LookupMtaStsDomainResults.


        :param well_known_value: The well_known_value of this LookupMtaStsDomainResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and well_known_value is None:  # noqa: E501
            raise ValueError("Invalid value for `well_known_value`, must not be `None`")  # noqa: E501

        self._well_known_value = well_known_value

    @property
    def errors(self):
        """Gets the errors of this LookupMtaStsDomainResults.  # noqa: E501


        :return: The errors of this LookupMtaStsDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this LookupMtaStsDomainResults.


        :param errors: The errors of this LookupMtaStsDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    @property
    def warnings(self):
        """Gets the warnings of this LookupMtaStsDomainResults.  # noqa: E501


        :return: The warnings of this LookupMtaStsDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this LookupMtaStsDomainResults.


        :param warnings: The warnings of this LookupMtaStsDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LookupMtaStsDomainResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LookupMtaStsDomainResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.o_auth_connection_api import OAuthConnectionApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestOAuthConnectionApi(unittest.TestCase):
    """OAuthConnectionApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.o_auth_connection_api.OAuthConnectionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_o_auth_connection(self):
        """Test case for create_o_auth_connection

        Create an OAuth connection  # noqa: E501
        """
        pass

    def test_exchange_authorization_token_and_create_or_update_inbox(self):
        """Test case for exchange_authorization_token_and_create_or_update_inbox

        Exchange authorization code for access token and create inbox  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmergencyAddress(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'sid': 'str',
        'user_id': 'str',
        'display_name': 'str',
        'customer_name': 'str',
        'address1': 'str',
        'city': 'str',
        'region': 'str',
        'postal_code': 'str',
        'phone_country': 'str',
        'account_sid': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'sid': 'sid',
        'user_id': 'userId',
        'display_name': 'displayName',
        'customer_name': 'customerName',
        'address1': 'address1',
        'city': 'city',
        'region': 'region',
        'postal_code': 'postalCode',
        'phone_country': 'phoneCountry',
        'account_sid': 'accountSid',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, sid=None, user_id=None, display_name=None, customer_name=None, address1=None, city=None, region=None, postal_code=None, phone_country=None, account_sid=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """EmergencyAddress - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._sid = None
        self._user_id = None
        self._display_name = None
        self._customer_name = None
        self._address1 = None
        self._city = None
        self._region = None
        self._postal_code = None
        self._phone_country = None
        self._account_sid = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.sid = sid
        self.user_id = user_id
        self.display_name = display_name
        self.customer_name = customer_name
        self.address1 = address1
        self.city = city
        self.region = region
        self.postal_code = postal_code
        self.phone_country = phone_country
        self.account_sid = account_sid
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this EmergencyAddress.  # noqa: E501


        :return: The id of this EmergencyAddress.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EmergencyAddress.


        :param id: The id of this EmergencyAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def sid(self):
        """Gets the sid of this EmergencyAddress.  # noqa: E501


        :return: The sid of this EmergencyAddress.  # noqa: E501
        :rtype: str
        """
        return self._sid

    @sid.setter
    def sid(self, sid):
        """Sets the sid of this EmergencyAddress.


        :param sid: The sid of this EmergencyAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sid is None:  # noqa: E501
            raise ValueError("Invalid value for `sid`, must not be `None`")  # noqa: E501

        self._sid = sid

    @property
    def user_id(self):
        """Gets the user_id of this EmergencyAddress.  # noqa: E501


        :return: The user_id of this EmergencyAddress.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this EmergencyAddress.


        :param user_id: The user_id of this EmergencyAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def display_name(self):
        """Gets the display_name of this EmergencyAddress.  # noqa: E501


        :return: The display_name of this EmergencyAddress.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this EmergencyAddress.


        :param display_name: The display_name of this EmergencyAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and display_name is None:  # noqa: E501
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def customer_name(self):
        """Gets the customer_name of this EmergencyAddress.  # noqa: E501


        :return: The customer_name of this EmergencyAddress.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this EmergencyAddress.


        :param customer_name: The customer_name of this EmergencyAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and customer_name is None:  # noqa: E501
            raise ValueError("Invalid value for `customer_name`, must not be `None`")  # noqa: E501

        self._customer_name = customer_name

    @property
    def address1(self):
        """Gets the address1 of this EmergencyAddress.  # noqa: E501


        :return: The address1 of this EmergencyAddress.  # noqa: E501
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """Sets the address1 of this EmergencyAddress.


        :param address1: The address1 of this EmergencyAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and address1 is None:  # noqa: E501
            raise ValueError("Invalid value for `address1`, must not be `None`")  # noqa: E501

        self._address1 = address1

    @property
    def city(self):
        """Gets the city of this EmergencyAddress.  # noqa: E501


        :return: The city of this EmergencyAddress.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this EmergencyAddress.


        :param city: The city of this EmergencyAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and city is None:  # noqa: E501
            raise ValueError("Invalid value for `city`, must not be `None`")  # noqa: E501

        self._city = city

    @property
    def region(self):
        """Gets the region of this EmergencyAddress.  # noqa: E501


        :return: The region of this EmergencyAddress.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this EmergencyAddress.


        :param region: The region of this EmergencyAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and region is None:  # noqa: E501
            raise ValueError("Invalid value for `region`, must not be `None`")  # noqa: E501

        self._region = region

    @property
    def postal_code(self):
        """Gets the postal_code of this EmergencyAddress.  # noqa: E501


        :return: The postal_code of this EmergencyAddress.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this EmergencyAddress.


        :param postal_code: The postal_code of this EmergencyAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and postal_code is None:  # noqa: E501
            raise ValueError("Invalid value for `postal_code`, must not be `None`")  # noqa: E501

        self._postal_code = postal_code

    @property
    def phone_country(self):
        """Gets the phone_country of this EmergencyAddress.  # noqa: E501


        :return: The phone_country of this EmergencyAddress.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this EmergencyAddress.


        :param phone_country: The phone_country of this EmergencyAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "CH", "PT", "NL", "IL", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def account_sid(self):
        """Gets the account_sid of this EmergencyAddress.  # noqa: E501


        :return: The account_sid of this EmergencyAddress.  # noqa: E501
        :rtype: str
        """
        return self._account_sid

    @account_sid.setter
    def account_sid(self, account_sid):
        """Sets the account_sid of this EmergencyAddress.


        :param account_sid: The account_sid of this EmergencyAddress.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and account_sid is None:  # noqa: E501
            raise ValueError("Invalid value for `account_sid`, must not be `None`")  # noqa: E501

        self._account_sid = account_sid

    @property
    def created_at(self):
        """Gets the created_at of this EmergencyAddress.  # noqa: E501


        :return: The created_at of this EmergencyAddress.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this EmergencyAddress.


        :param created_at: The created_at of this EmergencyAddress.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this EmergencyAddress.  # noqa: E501


        :return: The updated_at of this EmergencyAddress.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this EmergencyAddress.


        :param updated_at: The updated_at of this EmergencyAddress.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmergencyAddress):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmergencyAddress):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.connector_controller_api import ConnectorControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestConnectorControllerApi(unittest.TestCase):
    """ConnectorControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.connector_controller_api.ConnectorControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_connector(self):
        """Test case for create_connector

        Create an inbox connector  # noqa: E501
        """
        pass

    def test_create_connector_imap_connection(self):
        """Test case for create_connector_imap_connection

        Create an inbox connector IMAP connection  # noqa: E501
        """
        pass

    def test_create_connector_smtp_connection(self):
        """Test case for create_connector_smtp_connection

        Create an inbox connector SMTP connection  # noqa: E501
        """
        pass

    def test_create_connector_sync_settings(self):
        """Test case for create_connector_sync_settings

        Create an inbox connector sync settings  # noqa: E501
        """
        pass

    def test_create_connector_with_options(self):
        """Test case for create_connector_with_options

        Create an inbox connector with options  # noqa: E501
        """
        pass

    def test_delete_all_connector(self):
        """Test case for delete_all_connector

        Delete all inbox connectors  # noqa: E501
        """
        pass

    def test_delete_connector(self):
        """Test case for delete_connector

        Delete an inbox connector  # noqa: E501
        """
        pass

    def test_delete_connector_imap_connection(self):
        """Test case for delete_connector_imap_connection

        Delete an inbox connector IMAP connection  # noqa: E501
        """
        pass

    def test_delete_connector_smtp_connection(self):
        """Test case for delete_connector_smtp_connection

        Delete an inbox connector SMTP connection  # noqa: E501
        """
        pass

    def test_delete_connector_sync_settings(self):
        """Test case for delete_connector_sync_settings

        Create an inbox connector sync settings  # noqa: E501
        """
        pass

    def test_get_all_connector_events(self):
        """Test case for get_all_connector_events

        Get all inbox connector events  # noqa: E501
        """
        pass

    def test_get_connector(self):
        """Test case for get_connector

        Get an inbox connector  # noqa: E501
        """
        pass

    def test_get_connector_by_email_address(self):
        """Test case for get_connector_by_email_address

        Get connector by email address  # noqa: E501
        """
        pass

    def test_get_connector_by_inbox_id(self):
        """Test case for get_connector_by_inbox_id

        Get connector by inbox ID  # noqa: E501
        """
        pass

    def test_get_connector_by_name(self):
        """Test case for get_connector_by_name

        Get connector by name  # noqa: E501
        """
        pass

    def test_get_connector_event(self):
        """Test case for get_connector_event

        Get an inbox connector event  # noqa: E501
        """
        pass

    def test_get_connector_events(self):
        """Test case for get_connector_events

        Get an inbox connector events  # noqa: E501
        """
        pass

    def test_get_connector_imap_connection(self):
        """Test case for get_connector_imap_connection

        Get an inbox connector IMAP connection  # noqa: E501
        """
        pass

    def test_get_connector_provider_settings(self):
        """Test case for get_connector_provider_settings

        Get SMTP and IMAP connection settings for common mail providers  # noqa: E501
        """
        pass

    def test_get_connector_smtp_connection(self):
        """Test case for get_connector_smtp_connection

        Get an inbox connector SMTP connection  # noqa: E501
        """
        pass

    def test_get_connector_sync_settings(self):
        """Test case for get_connector_sync_settings

        Get an inbox connector sync settings  # noqa: E501
        """
        pass

    def test_get_connectors(self):
        """Test case for get_connectors

        Get inbox connectors  # noqa: E501
        """
        pass

    def test_send_email_from_connector(self):
        """Test case for send_email_from_connector

        Send from an inbox connector  # noqa: E501
        """
        pass

    def test_sync_connector(self):
        """Test case for sync_connector

        Sync an inbox connector  # noqa: E501
        """
        pass

    def test_test_connector_imap_connection(self):
        """Test case for test_connector_imap_connection

        Test an inbox connector IMAP connection  # noqa: E501
        """
        pass

    def test_test_connector_imap_connection_options(self):
        """Test case for test_connector_imap_connection_options

        Test an inbox connector IMAP connection options  # noqa: E501
        """
        pass

    def test_test_connector_smtp_connection(self):
        """Test case for test_connector_smtp_connection

        Test an inbox connector SMTP connection  # noqa: E501
        """
        pass

    def test_test_connector_smtp_connection_options(self):
        """Test case for test_connector_smtp_connection_options

        Test an inbox connector SMTP connection options  # noqa: E501
        """
        pass

    def test_update_connector(self):
        """Test case for update_connector

        Update an inbox connector  # noqa: E501
        """
        pass

    def test_update_connector_imap_connection(self):
        """Test case for update_connector_imap_connection

        Update an inbox connector IMAP connection  # noqa: E501
        """
        pass

    def test_update_connector_smtp_connection(self):
        """Test case for update_connector_smtp_connection

        Update an inbox connector SMTP connection  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class WebhookNewSmsPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message_id': 'str',
        'webhook_id': 'str',
        'event_name': 'str',
        'webhook_name': 'str',
        'sms_id': 'str',
        'user_id': 'str',
        'phone_number': 'str',
        'to_number': 'str',
        'from_number': 'str',
        'body': 'str',
        'read': 'bool'
    }

    attribute_map = {
        'message_id': 'messageId',
        'webhook_id': 'webhookId',
        'event_name': 'eventName',
        'webhook_name': 'webhookName',
        'sms_id': 'smsId',
        'user_id': 'userId',
        'phone_number': 'phoneNumber',
        'to_number': 'toNumber',
        'from_number': 'fromNumber',
        'body': 'body',
        'read': 'read'
    }

    def __init__(self, message_id=None, webhook_id=None, event_name=None, webhook_name=None, sms_id=None, user_id=None, phone_number=None, to_number=None, from_number=None, body=None, read=None, local_vars_configuration=None):  # noqa: E501
        """WebhookNewSmsPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._message_id = None
        self._webhook_id = None
        self._event_name = None
        self._webhook_name = None
        self._sms_id = None
        self._user_id = None
        self._phone_number = None
        self._to_number = None
        self._from_number = None
        self._body = None
        self._read = None
        self.discriminator = None

        self.message_id = message_id
        self.webhook_id = webhook_id
        self.event_name = event_name
        self.webhook_name = webhook_name
        self.sms_id = sms_id
        self.user_id = user_id
        self.phone_number = phone_number
        self.to_number = to_number
        self.from_number = from_number
        self.body = body
        self.read = read

    @property
    def message_id(self):
        """Gets the message_id of this WebhookNewSmsPayload.  # noqa: E501

        Idempotent message ID. Store this ID locally or in a database to prevent message duplication.  # noqa: E501

        :return: The message_id of this WebhookNewSmsPayload.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this WebhookNewSmsPayload.

        Idempotent message ID. Store this ID locally or in a database to prevent message duplication.  # noqa: E501

        :param message_id: The message_id of this WebhookNewSmsPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and message_id is None:  # noqa: E501
            raise ValueError("Invalid value for `message_id`, must not be `None`")  # noqa: E501

        self._message_id = message_id

    @property
    def webhook_id(self):
        """Gets the webhook_id of this WebhookNewSmsPayload.  # noqa: E501

        ID of webhook entity being triggered  # noqa: E501

        :return: The webhook_id of this WebhookNewSmsPayload.  # noqa: E501
        :rtype: str
        """
        return self._webhook_id

    @webhook_id.setter
    def webhook_id(self, webhook_id):
        """Sets the webhook_id of this WebhookNewSmsPayload.

        ID of webhook entity being triggered  # noqa: E501

        :param webhook_id: The webhook_id of this WebhookNewSmsPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and webhook_id is None:  # noqa: E501
            raise ValueError("Invalid value for `webhook_id`, must not be `None`")  # noqa: E501

        self._webhook_id = webhook_id

    @property
    def event_name(self):
        """Gets the event_name of this WebhookNewSmsPayload.  # noqa: E501

        Name of the event type webhook is being triggered for.  # noqa: E501

        :return: The event_name of this WebhookNewSmsPayload.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this WebhookNewSmsPayload.

        Name of the event type webhook is being triggered for.  # noqa: E501

        :param event_name: The event_name of this WebhookNewSmsPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event_name is None:  # noqa: E501
            raise ValueError("Invalid value for `event_name`, must not be `None`")  # noqa: E501
        allowed_values = ["EMAIL_RECEIVED", "NEW_EMAIL", "NEW_CONTACT", "NEW_ATTACHMENT", "EMAIL_OPENED", "EMAIL_READ", "DELIVERY_STATUS", "BOUNCE", "BOUNCE_RECIPIENT", "NEW_SMS", "NEW_GUEST_USER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_name not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_name` ({0}), must be one of {1}"  # noqa: E501
                .format(event_name, allowed_values)
            )

        self._event_name = event_name

    @property
    def webhook_name(self):
        """Gets the webhook_name of this WebhookNewSmsPayload.  # noqa: E501

        Name of the webhook being triggered  # noqa: E501

        :return: The webhook_name of this WebhookNewSmsPayload.  # noqa: E501
        :rtype: str
        """
        return self._webhook_name

    @webhook_name.setter
    def webhook_name(self, webhook_name):
        """Sets the webhook_name of this WebhookNewSmsPayload.

        Name of the webhook being triggered  # noqa: E501

        :param webhook_name: The webhook_name of this WebhookNewSmsPayload.  # noqa: E501
        :type: str
        """

        self._webhook_name = webhook_name

    @property
    def sms_id(self):
        """Gets the sms_id of this WebhookNewSmsPayload.  # noqa: E501

        ID of SMS message  # noqa: E501

        :return: The sms_id of this WebhookNewSmsPayload.  # noqa: E501
        :rtype: str
        """
        return self._sms_id

    @sms_id.setter
    def sms_id(self, sms_id):
        """Sets the sms_id of this WebhookNewSmsPayload.

        ID of SMS message  # noqa: E501

        :param sms_id: The sms_id of this WebhookNewSmsPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sms_id is None:  # noqa: E501
            raise ValueError("Invalid value for `sms_id`, must not be `None`")  # noqa: E501

        self._sms_id = sms_id

    @property
    def user_id(self):
        """Gets the user_id of this WebhookNewSmsPayload.  # noqa: E501

        User ID of event  # noqa: E501

        :return: The user_id of this WebhookNewSmsPayload.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this WebhookNewSmsPayload.

        User ID of event  # noqa: E501

        :param user_id: The user_id of this WebhookNewSmsPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def phone_number(self):
        """Gets the phone_number of this WebhookNewSmsPayload.  # noqa: E501

        ID of phone number receiving SMS  # noqa: E501

        :return: The phone_number of this WebhookNewSmsPayload.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this WebhookNewSmsPayload.

        ID of phone number receiving SMS  # noqa: E501

        :param phone_number: The phone_number of this WebhookNewSmsPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def to_number(self):
        """Gets the to_number of this WebhookNewSmsPayload.  # noqa: E501

        Recipient phone number  # noqa: E501

        :return: The to_number of this WebhookNewSmsPayload.  # noqa: E501
        :rtype: str
        """
        return self._to_number

    @to_number.setter
    def to_number(self, to_number):
        """Sets the to_number of this WebhookNewSmsPayload.

        Recipient phone number  # noqa: E501

        :param to_number: The to_number of this WebhookNewSmsPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and to_number is None:  # noqa: E501
            raise ValueError("Invalid value for `to_number`, must not be `None`")  # noqa: E501

        self._to_number = to_number

    @property
    def from_number(self):
        """Gets the from_number of this WebhookNewSmsPayload.  # noqa: E501

        Sender phone number  # noqa: E501

        :return: The from_number of this WebhookNewSmsPayload.  # noqa: E501
        :rtype: str
        """
        return self._from_number

    @from_number.setter
    def from_number(self, from_number):
        """Sets the from_number of this WebhookNewSmsPayload.

        Sender phone number  # noqa: E501

        :param from_number: The from_number of this WebhookNewSmsPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and from_number is None:  # noqa: E501
            raise ValueError("Invalid value for `from_number`, must not be `None`")  # noqa: E501

        self._from_number = from_number

    @property
    def body(self):
        """Gets the body of this WebhookNewSmsPayload.  # noqa: E501

        SMS message body  # noqa: E501

        :return: The body of this WebhookNewSmsPayload.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this WebhookNewSmsPayload.

        SMS message body  # noqa: E501

        :param body: The body of this WebhookNewSmsPayload.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and body is None:  # noqa: E501
            raise ValueError("Invalid value for `body`, must not be `None`")  # noqa: E501

        self._body = body

    @property
    def read(self):
        """Gets the read of this WebhookNewSmsPayload.  # noqa: E501

        SMS has been read  # noqa: E501

        :return: The read of this WebhookNewSmsPayload.  # noqa: E501
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """Sets the read of this WebhookNewSmsPayload.

        SMS has been read  # noqa: E501

        :param read: The read of this WebhookNewSmsPayload.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and read is None:  # noqa: E501
            raise ValueError("Invalid value for `read`, must not be `None`")  # noqa: E501

        self._read = read

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookNewSmsPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebhookNewSmsPayload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mailslurp_client.api_client import ApiClient
from mailslurp_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class InboxReplierControllerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_new_inbox_replier(self, create_inbox_replier_options, **kwargs):  # noqa: E501
        """Create an inbox replier  # noqa: E501

        Create a new inbox rule for reply toing, blocking, and allowing emails when sending and receiving  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_new_inbox_replier(create_inbox_replier_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateInboxReplierOptions create_inbox_replier_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: InboxReplierDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_new_inbox_replier_with_http_info(create_inbox_replier_options, **kwargs)  # noqa: E501

    def create_new_inbox_replier_with_http_info(self, create_inbox_replier_options, **kwargs):  # noqa: E501
        """Create an inbox replier  # noqa: E501

        Create a new inbox rule for reply toing, blocking, and allowing emails when sending and receiving  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_new_inbox_replier_with_http_info(create_inbox_replier_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateInboxReplierOptions create_inbox_replier_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(InboxReplierDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_inbox_replier_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_new_inbox_replier" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_inbox_replier_options' is set
        if self.api_client.client_side_validation and ('create_inbox_replier_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_inbox_replier_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_inbox_replier_options` when calling `create_new_inbox_replier`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_inbox_replier_options' in local_var_params:
            body_params = local_var_params['create_inbox_replier_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/repliers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InboxReplierDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_inbox_replier(self, id, **kwargs):  # noqa: E501
        """Delete an inbox replier  # noqa: E501

        Delete inbox replier  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_inbox_replier(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of inbox replier (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_inbox_replier_with_http_info(id, **kwargs)  # noqa: E501

    def delete_inbox_replier_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete an inbox replier  # noqa: E501

        Delete inbox replier  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_inbox_replier_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of inbox replier (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_inbox_replier" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `delete_inbox_replier`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/repliers/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_inbox_repliers(self, **kwargs):  # noqa: E501
        """Delete inbox repliers  # noqa: E501

        Delete inbox repliers. Accepts optional inboxId filter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_inbox_repliers(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str inbox_id: Optional inbox id to attach replier to
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_inbox_repliers_with_http_info(**kwargs)  # noqa: E501

    def delete_inbox_repliers_with_http_info(self, **kwargs):  # noqa: E501
        """Delete inbox repliers  # noqa: E501

        Delete inbox repliers. Accepts optional inboxId filter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_inbox_repliers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str inbox_id: Optional inbox id to attach replier to
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'inbox_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_inbox_repliers" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'inbox_id' in local_var_params and local_var_params['inbox_id'] is not None:  # noqa: E501
            query_params.append(('inboxId', local_var_params['inbox_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/repliers', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_inbox_replier_events(self, **kwargs):  # noqa: E501
        """Get inbox replier event list  # noqa: E501

        Get all inbox ruleset events  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_inbox_replier_events(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str inbox_replier_id: ID of inbox replier
        :param str inbox_id: ID of inbox
        :param str email_id: ID of email
        :param str sent_id: ID of sent
        :param int page: Optional page index in inbox replier event list pagination
        :param int size: Optional page size in inbox replier event list pagination
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageInboxReplierEvents
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_all_inbox_replier_events_with_http_info(**kwargs)  # noqa: E501

    def get_all_inbox_replier_events_with_http_info(self, **kwargs):  # noqa: E501
        """Get inbox replier event list  # noqa: E501

        Get all inbox ruleset events  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_inbox_replier_events_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str inbox_replier_id: ID of inbox replier
        :param str inbox_id: ID of inbox
        :param str email_id: ID of email
        :param str sent_id: ID of sent
        :param int page: Optional page index in inbox replier event list pagination
        :param int size: Optional page size in inbox replier event list pagination
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageInboxReplierEvents, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'inbox_replier_id',
            'inbox_id',
            'email_id',
            'sent_id',
            'page',
            'size',
            'sort'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_inbox_replier_events" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'inbox_replier_id' in local_var_params and local_var_params['inbox_replier_id'] is not None:  # noqa: E501
            query_params.append(('inboxReplierId', local_var_params['inbox_replier_id']))  # noqa: E501
        if 'inbox_id' in local_var_params and local_var_params['inbox_id'] is not None:  # noqa: E501
            query_params.append(('inboxId', local_var_params['inbox_id']))  # noqa: E501
        if 'email_id' in local_var_params and local_var_params['email_id'] is not None:  # noqa: E501
            query_params.append(('emailId', local_var_params['email_id']))  # noqa: E501
        if 'sent_id' in local_var_params and local_var_params['sent_id'] is not None:  # noqa: E501
            query_params.append(('sentId', local_var_params['sent_id']))  # noqa: E501
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/repliers/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageInboxReplierEvents',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_inbox_replier(self, id, **kwargs):  # noqa: E501
        """Get an inbox replier  # noqa: E501

        Get inbox ruleset  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_inbox_replier(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of inbox replier (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: InboxReplierDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_inbox_replier_with_http_info(id, **kwargs)  # noqa: E501

    def get_inbox_replier_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get an inbox replier  # noqa: E501

        Get inbox ruleset  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_inbox_replier_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of inbox replier (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(InboxReplierDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_inbox_replier" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_inbox_replier`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/repliers/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InboxReplierDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_inbox_replier_events(self, id, **kwargs):  # noqa: E501
        """Get an inbox replier event list  # noqa: E501

        Get inbox ruleset events  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_inbox_replier_events(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of inbox replier (required)
        :param int page: Optional page index in inbox replier event list pagination
        :param int size: Optional page size in inbox replier event list pagination
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageInboxReplierEvents
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_inbox_replier_events_with_http_info(id, **kwargs)  # noqa: E501

    def get_inbox_replier_events_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get an inbox replier event list  # noqa: E501

        Get inbox ruleset events  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_inbox_replier_events_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of inbox replier (required)
        :param int page: Optional page index in inbox replier event list pagination
        :param int size: Optional page size in inbox replier event list pagination
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageInboxReplierEvents, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'page',
            'size',
            'sort'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_inbox_replier_events" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_inbox_replier_events`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/repliers/{id}/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageInboxReplierEvents',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_inbox_repliers(self, **kwargs):  # noqa: E501
        """List inbox repliers  # noqa: E501

        List all repliers attached to an inbox  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_inbox_repliers(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str inbox_id: Optional inbox id to get repliers from
        :param int page: Optional page index in inbox replier list pagination
        :param int size: Optional page size in inbox replier list pagination
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageInboxReplierDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_inbox_repliers_with_http_info(**kwargs)  # noqa: E501

    def get_inbox_repliers_with_http_info(self, **kwargs):  # noqa: E501
        """List inbox repliers  # noqa: E501

        List all repliers attached to an inbox  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_inbox_repliers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str inbox_id: Optional inbox id to get repliers from
        :param int page: Optional page index in inbox replier list pagination
        :param int size: Optional page size in inbox replier list pagination
        :param str sort: Optional createdAt sort direction ASC or DESC
        :param datetime since: Filter by created at after the given timestamp
        :param datetime before: Filter by created at before the given timestamp
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageInboxReplierDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'inbox_id',
            'page',
            'size',
            'sort',
            'since',
            'before'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_inbox_repliers" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'inbox_id' in local_var_params and local_var_params['inbox_id'] is not None:  # noqa: E501
            query_params.append(('inboxId', local_var_params['inbox_id']))  # noqa: E501
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'size' in local_var_params and local_var_params['size'] is not None:  # noqa: E501
            query_params.append(('size', local_var_params['size']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/repliers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageInboxReplierDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_inbox_replier(self, id, update_inbox_replier_options, **kwargs):  # noqa: E501
        """Update an inbox replier  # noqa: E501

        Update inbox ruleset  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_inbox_replier(id, update_inbox_replier_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of inbox replier (required)
        :param UpdateInboxReplierOptions update_inbox_replier_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: InboxReplierDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_inbox_replier_with_http_info(id, update_inbox_replier_options, **kwargs)  # noqa: E501

    def update_inbox_replier_with_http_info(self, id, update_inbox_replier_options, **kwargs):  # noqa: E501
        """Update an inbox replier  # noqa: E501

        Update inbox ruleset  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_inbox_replier_with_http_info(id, update_inbox_replier_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: ID of inbox replier (required)
        :param UpdateInboxReplierOptions update_inbox_replier_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(InboxReplierDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'update_inbox_replier_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_inbox_replier" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `update_inbox_replier`")  # noqa: E501
        # verify the required parameter 'update_inbox_replier_options' is set
        if self.api_client.client_side_validation and ('update_inbox_replier_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_inbox_replier_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_inbox_replier_options` when calling `update_inbox_replier`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_inbox_replier_options' in local_var_params:
            body_params = local_var_params['update_inbox_replier_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/repliers/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InboxReplierDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ImapAccessDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'secure_imap_server_host': 'str',
        'secure_imap_server_port': 'int',
        'secure_imap_username': 'str',
        'secure_imap_password': 'str',
        'imap_server_host': 'str',
        'imap_server_port': 'int',
        'imap_username': 'str',
        'imap_password': 'str',
        'imap_mailbox': 'str'
    }

    attribute_map = {
        'secure_imap_server_host': 'secureImapServerHost',
        'secure_imap_server_port': 'secureImapServerPort',
        'secure_imap_username': 'secureImapUsername',
        'secure_imap_password': 'secureImapPassword',
        'imap_server_host': 'imapServerHost',
        'imap_server_port': 'imapServerPort',
        'imap_username': 'imapUsername',
        'imap_password': 'imapPassword',
        'imap_mailbox': 'imapMailbox'
    }

    def __init__(self, secure_imap_server_host=None, secure_imap_server_port=None, secure_imap_username=None, secure_imap_password=None, imap_server_host=None, imap_server_port=None, imap_username=None, imap_password=None, imap_mailbox=None, local_vars_configuration=None):  # noqa: E501
        """ImapAccessDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._secure_imap_server_host = None
        self._secure_imap_server_port = None
        self._secure_imap_username = None
        self._secure_imap_password = None
        self._imap_server_host = None
        self._imap_server_port = None
        self._imap_username = None
        self._imap_password = None
        self._imap_mailbox = None
        self.discriminator = None

        self.secure_imap_server_host = secure_imap_server_host
        self.secure_imap_server_port = secure_imap_server_port
        self.secure_imap_username = secure_imap_username
        self.secure_imap_password = secure_imap_password
        self.imap_server_host = imap_server_host
        self.imap_server_port = imap_server_port
        self.imap_username = imap_username
        self.imap_password = imap_password
        self.imap_mailbox = imap_mailbox

    @property
    def secure_imap_server_host(self):
        """Gets the secure_imap_server_host of this ImapAccessDetails.  # noqa: E501

        Secure TLS IMAP server host domain  # noqa: E501

        :return: The secure_imap_server_host of this ImapAccessDetails.  # noqa: E501
        :rtype: str
        """
        return self._secure_imap_server_host

    @secure_imap_server_host.setter
    def secure_imap_server_host(self, secure_imap_server_host):
        """Sets the secure_imap_server_host of this ImapAccessDetails.

        Secure TLS IMAP server host domain  # noqa: E501

        :param secure_imap_server_host: The secure_imap_server_host of this ImapAccessDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and secure_imap_server_host is None:  # noqa: E501
            raise ValueError("Invalid value for `secure_imap_server_host`, must not be `None`")  # noqa: E501

        self._secure_imap_server_host = secure_imap_server_host

    @property
    def secure_imap_server_port(self):
        """Gets the secure_imap_server_port of this ImapAccessDetails.  # noqa: E501

        Secure TLS IMAP server host port  # noqa: E501

        :return: The secure_imap_server_port of this ImapAccessDetails.  # noqa: E501
        :rtype: int
        """
        return self._secure_imap_server_port

    @secure_imap_server_port.setter
    def secure_imap_server_port(self, secure_imap_server_port):
        """Sets the secure_imap_server_port of this ImapAccessDetails.

        Secure TLS IMAP server host port  # noqa: E501

        :param secure_imap_server_port: The secure_imap_server_port of this ImapAccessDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and secure_imap_server_port is None:  # noqa: E501
            raise ValueError("Invalid value for `secure_imap_server_port`, must not be `None`")  # noqa: E501

        self._secure_imap_server_port = secure_imap_server_port

    @property
    def secure_imap_username(self):
        """Gets the secure_imap_username of this ImapAccessDetails.  # noqa: E501

        Secure TLS IMAP username for login  # noqa: E501

        :return: The secure_imap_username of this ImapAccessDetails.  # noqa: E501
        :rtype: str
        """
        return self._secure_imap_username

    @secure_imap_username.setter
    def secure_imap_username(self, secure_imap_username):
        """Sets the secure_imap_username of this ImapAccessDetails.

        Secure TLS IMAP username for login  # noqa: E501

        :param secure_imap_username: The secure_imap_username of this ImapAccessDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and secure_imap_username is None:  # noqa: E501
            raise ValueError("Invalid value for `secure_imap_username`, must not be `None`")  # noqa: E501

        self._secure_imap_username = secure_imap_username

    @property
    def secure_imap_password(self):
        """Gets the secure_imap_password of this ImapAccessDetails.  # noqa: E501

        Secure TLS IMAP password for login  # noqa: E501

        :return: The secure_imap_password of this ImapAccessDetails.  # noqa: E501
        :rtype: str
        """
        return self._secure_imap_password

    @secure_imap_password.setter
    def secure_imap_password(self, secure_imap_password):
        """Sets the secure_imap_password of this ImapAccessDetails.

        Secure TLS IMAP password for login  # noqa: E501

        :param secure_imap_password: The secure_imap_password of this ImapAccessDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and secure_imap_password is None:  # noqa: E501
            raise ValueError("Invalid value for `secure_imap_password`, must not be `None`")  # noqa: E501

        self._secure_imap_password = secure_imap_password

    @property
    def imap_server_host(self):
        """Gets the imap_server_host of this ImapAccessDetails.  # noqa: E501

        IMAP server host domain  # noqa: E501

        :return: The imap_server_host of this ImapAccessDetails.  # noqa: E501
        :rtype: str
        """
        return self._imap_server_host

    @imap_server_host.setter
    def imap_server_host(self, imap_server_host):
        """Sets the imap_server_host of this ImapAccessDetails.

        IMAP server host domain  # noqa: E501

        :param imap_server_host: The imap_server_host of this ImapAccessDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and imap_server_host is None:  # noqa: E501
            raise ValueError("Invalid value for `imap_server_host`, must not be `None`")  # noqa: E501

        self._imap_server_host = imap_server_host

    @property
    def imap_server_port(self):
        """Gets the imap_server_port of this ImapAccessDetails.  # noqa: E501

        IMAP server host port  # noqa: E501

        :return: The imap_server_port of this ImapAccessDetails.  # noqa: E501
        :rtype: int
        """
        return self._imap_server_port

    @imap_server_port.setter
    def imap_server_port(self, imap_server_port):
        """Sets the imap_server_port of this ImapAccessDetails.

        IMAP server host port  # noqa: E501

        :param imap_server_port: The imap_server_port of this ImapAccessDetails.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and imap_server_port is None:  # noqa: E501
            raise ValueError("Invalid value for `imap_server_port`, must not be `None`")  # noqa: E501

        self._imap_server_port = imap_server_port

    @property
    def imap_username(self):
        """Gets the imap_username of this ImapAccessDetails.  # noqa: E501

        IMAP username for login  # noqa: E501

        :return: The imap_username of this ImapAccessDetails.  # noqa: E501
        :rtype: str
        """
        return self._imap_username

    @imap_username.setter
    def imap_username(self, imap_username):
        """Sets the imap_username of this ImapAccessDetails.

        IMAP username for login  # noqa: E501

        :param imap_username: The imap_username of this ImapAccessDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and imap_username is None:  # noqa: E501
            raise ValueError("Invalid value for `imap_username`, must not be `None`")  # noqa: E501

        self._imap_username = imap_username

    @property
    def imap_password(self):
        """Gets the imap_password of this ImapAccessDetails.  # noqa: E501

        IMAP password for login  # noqa: E501

        :return: The imap_password of this ImapAccessDetails.  # noqa: E501
        :rtype: str
        """
        return self._imap_password

    @imap_password.setter
    def imap_password(self, imap_password):
        """Sets the imap_password of this ImapAccessDetails.

        IMAP password for login  # noqa: E501

        :param imap_password: The imap_password of this ImapAccessDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and imap_password is None:  # noqa: E501
            raise ValueError("Invalid value for `imap_password`, must not be `None`")  # noqa: E501

        self._imap_password = imap_password

    @property
    def imap_mailbox(self):
        """Gets the imap_mailbox of this ImapAccessDetails.  # noqa: E501

        IMAP mailbox to SELECT  # noqa: E501

        :return: The imap_mailbox of this ImapAccessDetails.  # noqa: E501
        :rtype: str
        """
        return self._imap_mailbox

    @imap_mailbox.setter
    def imap_mailbox(self, imap_mailbox):
        """Sets the imap_mailbox of this ImapAccessDetails.

        IMAP mailbox to SELECT  # noqa: E501

        :param imap_mailbox: The imap_mailbox of this ImapAccessDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and imap_mailbox is None:  # noqa: E501
            raise ValueError("Invalid value for `imap_mailbox`, must not be `None`")  # noqa: E501

        self._imap_mailbox = imap_mailbox

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImapAccessDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImapAccessDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.inbox_controller_api import InboxControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestInboxControllerApi(unittest.TestCase):
    """InboxControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.inbox_controller_api.InboxControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_scheduled_job(self):
        """Test case for cancel_scheduled_job

        Cancel a scheduled email job  # noqa: E501
        """
        pass

    def test_create_inbox(self):
        """Test case for create_inbox

        Create an inbox email address. An inbox has a real email address and can send and receive emails. Inboxes can be either `SMTP` or `HTTP` inboxes.  # noqa: E501
        """
        pass

    def test_create_inbox_ruleset(self):
        """Test case for create_inbox_ruleset

        Create an inbox ruleset  # noqa: E501
        """
        pass

    def test_create_inbox_with_defaults(self):
        """Test case for create_inbox_with_defaults

        Create an inbox with default options. Uses MailSlurp domain pool address and is private.  # noqa: E501
        """
        pass

    def test_create_inbox_with_options(self):
        """Test case for create_inbox_with_options

        Create an inbox with options. Extended options for inbox creation.  # noqa: E501
        """
        pass

    def test_delete_all_inbox_emails(self):
        """Test case for delete_all_inbox_emails

        Delete all emails in a given inboxes.  # noqa: E501
        """
        pass

    def test_delete_all_inboxes(self):
        """Test case for delete_all_inboxes

        Delete all inboxes  # noqa: E501
        """
        pass

    def test_delete_all_inboxes_by_description(self):
        """Test case for delete_all_inboxes_by_description

        Delete inboxes by description  # noqa: E501
        """
        pass

    def test_delete_all_inboxes_by_name(self):
        """Test case for delete_all_inboxes_by_name

        Delete inboxes by name  # noqa: E501
        """
        pass

    def test_delete_all_inboxes_by_tag(self):
        """Test case for delete_all_inboxes_by_tag

        Delete inboxes by tag  # noqa: E501
        """
        pass

    def test_delete_inbox(self):
        """Test case for delete_inbox

        Delete inbox  # noqa: E501
        """
        pass

    def test_does_inbox_exist(self):
        """Test case for does_inbox_exist

        Does inbox exist  # noqa: E501
        """
        pass

    def test_does_inbox_have_automations(self):
        """Test case for does_inbox_have_automations

        Does inbox have automations  # noqa: E501
        """
        pass

    def test_flush_expired(self):
        """Test case for flush_expired

        Remove expired inboxes  # noqa: E501
        """
        pass

    def test_get_all_inboxes(self):
        """Test case for get_all_inboxes

        List All Inboxes Paginated  # noqa: E501
        """
        pass

    def test_get_all_inboxes_offset_paginated(self):
        """Test case for get_all_inboxes_offset_paginated

        List All Inboxes Offset Paginated  # noqa: E501
        """
        pass

    def test_get_all_plus_addresses(self):
        """Test case for get_all_plus_addresses

        Get all sub address plus address aliases for an inbox  # noqa: E501
        """
        pass

    def test_get_all_scheduled_jobs(self):
        """Test case for get_all_scheduled_jobs

        Get all scheduled email sending jobs for account  # noqa: E501
        """
        pass

    def test_get_delivery_statuses_by_inbox_id(self):
        """Test case for get_delivery_statuses_by_inbox_id

        """
        pass

    def test_get_emails(self):
        """Test case for get_emails

        Get emails in an Inbox. This method is not idempotent as it allows retries and waits if you want certain conditions to be met before returning. For simple listing and sorting of known emails use the email controller instead.  # noqa: E501
        """
        pass

    def test_get_imap_access(self):
        """Test case for get_imap_access

        """
        pass

    def test_get_imap_smtp_access(self):
        """Test case for get_imap_smtp_access

        """
        pass

    def test_get_imap_smtp_access_env(self):
        """Test case for get_imap_smtp_access_env

        """
        pass

    def test_get_imap_smtp_access_servers(self):
        """Test case for get_imap_smtp_access_servers

        """
        pass

    def test_get_inbox(self):
        """Test case for get_inbox

        Get Inbox. Returns properties of an inbox.  # noqa: E501
        """
        pass

    def test_get_inbox_by_email_address(self):
        """Test case for get_inbox_by_email_address

        Search for an inbox with the provided email address  # noqa: E501
        """
        pass

    def test_get_inbox_by_name(self):
        """Test case for get_inbox_by_name

        Search for an inbox with the given name  # noqa: E501
        """
        pass

    def test_get_inbox_count(self):
        """Test case for get_inbox_count

        Get total inbox count  # noqa: E501
        """
        pass

    def test_get_inbox_email_count(self):
        """Test case for get_inbox_email_count

        Get email count in inbox  # noqa: E501
        """
        pass

    def test_get_inbox_emails_paginated(self):
        """Test case for get_inbox_emails_paginated

        Get inbox emails paginated  # noqa: E501
        """
        pass

    def test_get_inbox_ids(self):
        """Test case for get_inbox_ids

        Get all inbox IDs  # noqa: E501
        """
        pass

    def test_get_inbox_plus_address(self):
        """Test case for get_inbox_plus_address

        Get sub address plus address for an inbox  # noqa: E501
        """
        pass

    def test_get_inbox_plus_address_by_id(self):
        """Test case for get_inbox_plus_address_by_id

        Get sub address plus address by ID  # noqa: E501
        """
        pass

    def test_get_inbox_plus_address_emails(self):
        """Test case for get_inbox_plus_address_emails

        Get emails for a given inbox plus address  # noqa: E501
        """
        pass

    def test_get_inbox_plus_address_emails_for_plus_address_id(self):
        """Test case for get_inbox_plus_address_emails_for_plus_address_id

        Get emails for a given inbox plus address  # noqa: E501
        """
        pass

    def test_get_inbox_plus_addresses(self):
        """Test case for get_inbox_plus_addresses

        Get sub address plus address aliases for an inbox  # noqa: E501
        """
        pass

    def test_get_inbox_sent_count(self):
        """Test case for get_inbox_sent_count

        Get sent email count in inbox  # noqa: E501
        """
        pass

    def test_get_inbox_sent_emails(self):
        """Test case for get_inbox_sent_emails

        Get Inbox Sent Emails  # noqa: E501
        """
        pass

    def test_get_inbox_tags(self):
        """Test case for get_inbox_tags

        Get inbox tags  # noqa: E501
        """
        pass

    def test_get_inbox_tags_paginated(self):
        """Test case for get_inbox_tags_paginated

        Get inbox tags paginated  # noqa: E501
        """
        pass

    def test_get_inboxes(self):
        """Test case for get_inboxes

        List Inboxes and email addresses  # noqa: E501
        """
        pass

    def test_get_inboxes_by_tag(self):
        """Test case for get_inboxes_by_tag

        Get inboxes for a tag  # noqa: E501
        """
        pass

    def test_get_latest_email_in_inbox(self):
        """Test case for get_latest_email_in_inbox

        Get latest email in an inbox. Use `WaitForController` to get emails that may not have arrived yet.  # noqa: E501
        """
        pass

    def test_get_organization_inboxes(self):
        """Test case for get_organization_inboxes

        List Organization Inboxes Paginated  # noqa: E501
        """
        pass

    def test_get_outboxes(self):
        """Test case for get_outboxes

        List all inboxes with sent emails  # noqa: E501
        """
        pass

    def test_get_scheduled_job(self):
        """Test case for get_scheduled_job

        Get a scheduled email job  # noqa: E501
        """
        pass

    def test_get_scheduled_jobs_by_inbox_id(self):
        """Test case for get_scheduled_jobs_by_inbox_id

        Get all scheduled email sending jobs for the inbox  # noqa: E501
        """
        pass

    def test_get_smtp_access(self):
        """Test case for get_smtp_access

        """
        pass

    def test_is_email_address_available(self):
        """Test case for is_email_address_available

        Is email address available  # noqa: E501
        """
        pass

    def test_list_inbox_rulesets(self):
        """Test case for list_inbox_rulesets

        List inbox rulesets  # noqa: E501
        """
        pass

    def test_list_inbox_tracking_pixels(self):
        """Test case for list_inbox_tracking_pixels

        List inbox tracking pixels  # noqa: E501
        """
        pass

    def test_search_inboxes(self):
        """Test case for search_inboxes

        Search all inboxes and return matching inboxes  # noqa: E501
        """
        pass

    def test_send_email(self):
        """Test case for send_email

        Send Email  # noqa: E501
        """
        pass

    def test_send_email_and_confirm(self):
        """Test case for send_email_and_confirm

        Send email and return sent confirmation  # noqa: E501
        """
        pass

    def test_send_email_with_queue(self):
        """Test case for send_email_with_queue

        Send email with queue  # noqa: E501
        """
        pass

    def test_send_smtp_envelope(self):
        """Test case for send_smtp_envelope

        Send email using an SMTP mail envelope and message body and return sent confirmation  # noqa: E501
        """
        pass

    def test_send_test_email(self):
        """Test case for send_test_email

        Send a test email to inbox  # noqa: E501
        """
        pass

    def test_send_with_schedule(self):
        """Test case for send_with_schedule

        Send email with with delay or schedule  # noqa: E501
        """
        pass

    def test_set_inbox_favourited(self):
        """Test case for set_inbox_favourited

        Set inbox favourited state  # noqa: E501
        """
        pass

    def test_update_imap_access(self):
        """Test case for update_imap_access

        """
        pass

    def test_update_inbox(self):
        """Test case for update_inbox

        Update Inbox. Change name and description. Email address is not editable.  # noqa: E501
        """
        pass

    def test_update_smtp_access(self):
        """Test case for update_smtp_access

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreatePhoneNumberOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'phone_country': 'str',
        'name': 'str',
        'description': 'str',
        'schedule': 'str'
    }

    attribute_map = {
        'phone_country': 'phoneCountry',
        'name': 'name',
        'description': 'description',
        'schedule': 'schedule'
    }

    def __init__(self, phone_country=None, name=None, description=None, schedule=None, local_vars_configuration=None):  # noqa: E501
        """CreatePhoneNumberOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._phone_country = None
        self._name = None
        self._description = None
        self._schedule = None
        self.discriminator = None

        self.phone_country = phone_country
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if schedule is not None:
            self.schedule = schedule

    @property
    def phone_country(self):
        """Gets the phone_country of this CreatePhoneNumberOptions.  # noqa: E501


        :return: The phone_country of this CreatePhoneNumberOptions.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this CreatePhoneNumberOptions.


        :param phone_country: The phone_country of this CreatePhoneNumberOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "CH", "PT", "NL", "IL", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def name(self):
        """Gets the name of this CreatePhoneNumberOptions.  # noqa: E501


        :return: The name of this CreatePhoneNumberOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreatePhoneNumberOptions.


        :param name: The name of this CreatePhoneNumberOptions.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this CreatePhoneNumberOptions.  # noqa: E501


        :return: The description of this CreatePhoneNumberOptions.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreatePhoneNumberOptions.


        :param description: The description of this CreatePhoneNumberOptions.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def schedule(self):
        """Gets the schedule of this CreatePhoneNumberOptions.  # noqa: E501


        :return: The schedule of this CreatePhoneNumberOptions.  # noqa: E501
        :rtype: str
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """Sets the schedule of this CreatePhoneNumberOptions.


        :param schedule: The schedule of this CreatePhoneNumberOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["MONTHLY", "YEARLY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and schedule not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `schedule` ({0}), must be one of {1}"  # noqa: E501
                .format(schedule, allowed_values)
            )

        self._schedule = schedule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreatePhoneNumberOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreatePhoneNumberOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class TrackingPixelProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'inbox_id': 'str',
        'sent_email_id': 'str',
        'created_at': 'datetime',
        'recipient': 'str',
        'seen': 'bool',
        'seen_at': 'datetime',
        'name': 'str',
        'id': 'str'
    }

    attribute_map = {
        'user_id': 'userId',
        'inbox_id': 'inboxId',
        'sent_email_id': 'sentEmailId',
        'created_at': 'createdAt',
        'recipient': 'recipient',
        'seen': 'seen',
        'seen_at': 'seenAt',
        'name': 'name',
        'id': 'id'
    }

    def __init__(self, user_id=None, inbox_id=None, sent_email_id=None, created_at=None, recipient=None, seen=None, seen_at=None, name=None, id=None, local_vars_configuration=None):  # noqa: E501
        """TrackingPixelProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._inbox_id = None
        self._sent_email_id = None
        self._created_at = None
        self._recipient = None
        self._seen = None
        self._seen_at = None
        self._name = None
        self._id = None
        self.discriminator = None

        self.user_id = user_id
        if inbox_id is not None:
            self.inbox_id = inbox_id
        if sent_email_id is not None:
            self.sent_email_id = sent_email_id
        self.created_at = created_at
        if recipient is not None:
            self.recipient = recipient
        self.seen = seen
        if seen_at is not None:
            self.seen_at = seen_at
        if name is not None:
            self.name = name
        self.id = id

    @property
    def user_id(self):
        """Gets the user_id of this TrackingPixelProjection.  # noqa: E501


        :return: The user_id of this TrackingPixelProjection.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this TrackingPixelProjection.


        :param user_id: The user_id of this TrackingPixelProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def inbox_id(self):
        """Gets the inbox_id of this TrackingPixelProjection.  # noqa: E501


        :return: The inbox_id of this TrackingPixelProjection.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this TrackingPixelProjection.


        :param inbox_id: The inbox_id of this TrackingPixelProjection.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def sent_email_id(self):
        """Gets the sent_email_id of this TrackingPixelProjection.  # noqa: E501


        :return: The sent_email_id of this TrackingPixelProjection.  # noqa: E501
        :rtype: str
        """
        return self._sent_email_id

    @sent_email_id.setter
    def sent_email_id(self, sent_email_id):
        """Sets the sent_email_id of this TrackingPixelProjection.


        :param sent_email_id: The sent_email_id of this TrackingPixelProjection.  # noqa: E501
        :type: str
        """

        self._sent_email_id = sent_email_id

    @property
    def created_at(self):
        """Gets the created_at of this TrackingPixelProjection.  # noqa: E501


        :return: The created_at of this TrackingPixelProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this TrackingPixelProjection.


        :param created_at: The created_at of this TrackingPixelProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def recipient(self):
        """Gets the recipient of this TrackingPixelProjection.  # noqa: E501


        :return: The recipient of this TrackingPixelProjection.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this TrackingPixelProjection.


        :param recipient: The recipient of this TrackingPixelProjection.  # noqa: E501
        :type: str
        """

        self._recipient = recipient

    @property
    def seen(self):
        """Gets the seen of this TrackingPixelProjection.  # noqa: E501


        :return: The seen of this TrackingPixelProjection.  # noqa: E501
        :rtype: bool
        """
        return self._seen

    @seen.setter
    def seen(self, seen):
        """Sets the seen of this TrackingPixelProjection.


        :param seen: The seen of this TrackingPixelProjection.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and seen is None:  # noqa: E501
            raise ValueError("Invalid value for `seen`, must not be `None`")  # noqa: E501

        self._seen = seen

    @property
    def seen_at(self):
        """Gets the seen_at of this TrackingPixelProjection.  # noqa: E501


        :return: The seen_at of this TrackingPixelProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._seen_at

    @seen_at.setter
    def seen_at(self, seen_at):
        """Sets the seen_at of this TrackingPixelProjection.


        :param seen_at: The seen_at of this TrackingPixelProjection.  # noqa: E501
        :type: datetime
        """

        self._seen_at = seen_at

    @property
    def name(self):
        """Gets the name of this TrackingPixelProjection.  # noqa: E501


        :return: The name of this TrackingPixelProjection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TrackingPixelProjection.


        :param name: The name of this TrackingPixelProjection.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this TrackingPixelProjection.  # noqa: E501


        :return: The id of this TrackingPixelProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TrackingPixelProjection.


        :param id: The id of this TrackingPixelProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TrackingPixelProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TrackingPixelProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mailslurp_client
from mailslurp_client.models.generate_structured_content_email_options import GenerateStructuredContentEmailOptions  # noqa: E501
from mailslurp_client.rest import ApiException

class TestGenerateStructuredContentEmailOptions(unittest.TestCase):
    """GenerateStructuredContentEmailOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GenerateStructuredContentEmailOptions
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mailslurp_client.models.generate_structured_content_email_options.GenerateStructuredContentEmailOptions()  # noqa: E501
        if include_optional :
            return GenerateStructuredContentEmailOptions(
                email_id = '0', 
                content_selector = 'RAW', 
                instructions = '0', 
                output_schema = mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                    any_of = [
                        mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                            default = mailslurp_client.models.meta_data.metaData(), 
                            description = '0', 
                            enum = [
                                '0'
                                ], 
                            example = mailslurp_client.models.meta_data.metaData(), 
                            format = '0', 
                            items = mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                default = mailslurp_client.models.meta_data.metaData(), 
                                description = '0', 
                                example = mailslurp_client.models.meta_data.metaData(), 
                                format = '0', 
                                max_items = 0, 
                                min_items = 0, 
                                max_length = 0, 
                                min_length = 0, 
                                pattern = '0', 
                                properties = {
                                    'key' : mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                        default = mailslurp_client.models.meta_data.metaData(), 
                                        description = '0', 
                                        example = mailslurp_client.models.meta_data.metaData(), 
                                        format = '0', 
                                        max_items = 0, 
                                        min_items = 0, 
                                        max_length = 0, 
                                        min_length = 0, 
                                        pattern = '0', 
                                        property_ordering = [
                                            '0'
                                            ], 
                                        required = [
                                            '0'
                                            ], 
                                        max_properties = 0, 
                                        min_properties = 0, 
                                        maximum = 1.337, 
                                        minimum = 1.337, 
                                        nullable = True, 
                                        title = '0', 
                                        type = 'string', )
                                    }, 
                                property_ordering = [
                                    '0'
                                    ], 
                                required = [
                                    '0'
                                    ], 
                                max_properties = 0, 
                                min_properties = 0, 
                                maximum = 1.337, 
                                minimum = 1.337, 
                                nullable = True, 
                                title = '0', 
                                type = 'string', ), 
                            max_items = 0, 
                            min_items = 0, 
                            max_length = 0, 
                            min_length = 0, 
                            pattern = '0', 
                            properties = {
                                'key' : mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                    default = mailslurp_client.models.meta_data.metaData(), 
                                    description = '0', 
                                    example = mailslurp_client.models.meta_data.metaData(), 
                                    format = '0', 
                                    max_items = 0, 
                                    min_items = 0, 
                                    max_length = 0, 
                                    min_length = 0, 
                                    pattern = '0', 
                                    max_properties = 0, 
                                    min_properties = 0, 
                                    maximum = 1.337, 
                                    minimum = 1.337, 
                                    nullable = True, 
                                    title = '0', 
                                    type = 'string', )
                                }, 
                            property_ordering = [
                                '0'
                                ], 
                            required = [
                                '0'
                                ], 
                            max_properties = 0, 
                            min_properties = 0, 
                            maximum = 1.337, 
                            minimum = 1.337, 
                            nullable = True, 
                            title = '0', 
                            type = 'string', )
                        ], 
                    default = mailslurp_client.models.meta_data.metaData(), 
                    description = '0', 
                    enum = [
                        '0'
                        ], 
                    example = mailslurp_client.models.meta_data.metaData(), 
                    format = '0', 
                    items = mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                        default = mailslurp_client.models.meta_data.metaData(), 
                        description = '0', 
                        example = mailslurp_client.models.meta_data.metaData(), 
                        format = '0', 
                        max_items = 0, 
                        min_items = 0, 
                        max_length = 0, 
                        min_length = 0, 
                        pattern = '0', 
                        max_properties = 0, 
                        min_properties = 0, 
                        maximum = 1.337, 
                        minimum = 1.337, 
                        nullable = True, 
                        title = '0', 
                        type = 'string', ), 
                    max_items = 0, 
                    min_items = 0, 
                    max_length = 0, 
                    min_length = 0, 
                    pattern = '0', 
                    properties = {
                        'key' : mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                            default = mailslurp_client.models.meta_data.metaData(), 
                            description = '0', 
                            example = mailslurp_client.models.meta_data.metaData(), 
                            format = '0', 
                            max_items = 0, 
                            min_items = 0, 
                            max_length = 0, 
                            min_length = 0, 
                            pattern = '0', 
                            max_properties = 0, 
                            min_properties = 0, 
                            maximum = 1.337, 
                            minimum = 1.337, 
                            nullable = True, 
                            title = '0', 
                            type = 'string', )
                        }, 
                    property_ordering = [
                        '0'
                        ], 
                    required = [
                        '0'
                        ], 
                    max_properties = 0, 
                    min_properties = 0, 
                    maximum = 1.337, 
                    minimum = 1.337, 
                    nullable = True, 
                    title = '0', 
                    type = 'string', )
            )
        else :
            return GenerateStructuredContentEmailOptions(
                email_id = '0',
                output_schema = mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                    any_of = [
                        mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                            default = mailslurp_client.models.meta_data.metaData(), 
                            description = '0', 
                            enum = [
                                '0'
                                ], 
                            example = mailslurp_client.models.meta_data.metaData(), 
                            format = '0', 
                            items = mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                default = mailslurp_client.models.meta_data.metaData(), 
                                description = '0', 
                                example = mailslurp_client.models.meta_data.metaData(), 
                                format = '0', 
                                max_items = 0, 
                                min_items = 0, 
                                max_length = 0, 
                                min_length = 0, 
                                pattern = '0', 
                                properties = {
                                    'key' : mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                        default = mailslurp_client.models.meta_data.metaData(), 
                                        description = '0', 
                                        example = mailslurp_client.models.meta_data.metaData(), 
                                        format = '0', 
                                        max_items = 0, 
                                        min_items = 0, 
                                        max_length = 0, 
                                        min_length = 0, 
                                        pattern = '0', 
                                        property_ordering = [
                                            '0'
                                            ], 
                                        required = [
                                            '0'
                                            ], 
                                        max_properties = 0, 
                                        min_properties = 0, 
                                        maximum = 1.337, 
                                        minimum = 1.337, 
                                        nullable = True, 
                                        title = '0', 
                                        type = 'string', )
                                    }, 
                                property_ordering = [
                                    '0'
                                    ], 
                                required = [
                                    '0'
                                    ], 
                                max_properties = 0, 
                                min_properties = 0, 
                                maximum = 1.337, 
                                minimum = 1.337, 
                                nullable = True, 
                                title = '0', 
                                type = 'string', ), 
                            max_items = 0, 
                            min_items = 0, 
                            max_length = 0, 
                            min_length = 0, 
                            pattern = '0', 
                            properties = {
                                'key' : mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                                    default = mailslurp_client.models.meta_data.metaData(), 
                                    description = '0', 
                                    example = mailslurp_client.models.meta_data.metaData(), 
                                    format = '0', 
                                    max_items = 0, 
                                    min_items = 0, 
                                    max_length = 0, 
                                    min_length = 0, 
                                    pattern = '0', 
                                    max_properties = 0, 
                                    min_properties = 0, 
                                    maximum = 1.337, 
                                    minimum = 1.337, 
                                    nullable = True, 
                                    title = '0', 
                                    type = 'string', )
                                }, 
                            property_ordering = [
                                '0'
                                ], 
                            required = [
                                '0'
                                ], 
                            max_properties = 0, 
                            min_properties = 0, 
                            maximum = 1.337, 
                            minimum = 1.337, 
                            nullable = True, 
                            title = '0', 
                            type = 'string', )
                        ], 
                    default = mailslurp_client.models.meta_data.metaData(), 
                    description = '0', 
                    enum = [
                        '0'
                        ], 
                    example = mailslurp_client.models.meta_data.metaData(), 
                    format = '0', 
                    items = mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                        default = mailslurp_client.models.meta_data.metaData(), 
                        description = '0', 
                        example = mailslurp_client.models.meta_data.metaData(), 
                        format = '0', 
                        max_items = 0, 
                        min_items = 0, 
                        max_length = 0, 
                        min_length = 0, 
                        pattern = '0', 
                        max_properties = 0, 
                        min_properties = 0, 
                        maximum = 1.337, 
                        minimum = 1.337, 
                        nullable = True, 
                        title = '0', 
                        type = 'string', ), 
                    max_items = 0, 
                    min_items = 0, 
                    max_length = 0, 
                    min_length = 0, 
                    pattern = '0', 
                    properties = {
                        'key' : mailslurp_client.models.structured_output_schema.StructuredOutputSchema(
                            default = mailslurp_client.models.meta_data.metaData(), 
                            description = '0', 
                            example = mailslurp_client.models.meta_data.metaData(), 
                            format = '0', 
                            max_items = 0, 
                            min_items = 0, 
                            max_length = 0, 
                            min_length = 0, 
                            pattern = '0', 
                            max_properties = 0, 
                            min_properties = 0, 
                            maximum = 1.337, 
                            minimum = 1.337, 
                            nullable = True, 
                            title = '0', 
                            type = 'string', )
                        }, 
                    property_ordering = [
                        '0'
                        ], 
                    required = [
                        '0'
                        ], 
                    max_properties = 0, 
                    min_properties = 0, 
                    maximum = 1.337, 
                    minimum = 1.337, 
                    nullable = True, 
                    title = '0', 
                    type = 'string', ),
        )

    def testGenerateStructuredContentEmailOptions(self):
        """Test GenerateStructuredContentEmailOptions"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.sent_emails_controller_api import SentEmailsControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestSentEmailsControllerApi(unittest.TestCase):
    """SentEmailsControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.sent_emails_controller_api.SentEmailsControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_all_sent_emails(self):
        """Test case for delete_all_sent_emails

        Delete all sent email receipts  # noqa: E501
        """
        pass

    def test_delete_sent_email(self):
        """Test case for delete_sent_email

        Delete sent email receipt  # noqa: E501
        """
        pass

    def test_get_all_sent_tracking_pixels(self):
        """Test case for get_all_sent_tracking_pixels

        """
        pass

    def test_get_raw_sent_email_contents(self):
        """Test case for get_raw_sent_email_contents

        Get raw sent email string. Returns unparsed raw SMTP message with headers and body.  # noqa: E501
        """
        pass

    def test_get_raw_sent_email_json(self):
        """Test case for get_raw_sent_email_json

        Get raw sent email in JSON. Unparsed SMTP message in JSON wrapper format.  # noqa: E501
        """
        pass

    def test_get_sent_delivery_status(self):
        """Test case for get_sent_delivery_status

        """
        pass

    def test_get_sent_delivery_statuses(self):
        """Test case for get_sent_delivery_statuses

        """
        pass

    def test_get_sent_delivery_statuses_by_sent_id(self):
        """Test case for get_sent_delivery_statuses_by_sent_id

        """
        pass

    def test_get_sent_email(self):
        """Test case for get_sent_email

        Get sent email receipt  # noqa: E501
        """
        pass

    def test_get_sent_email_html_content(self):
        """Test case for get_sent_email_html_content

        Get sent email HTML content  # noqa: E501
        """
        pass

    def test_get_sent_email_preview_ur_ls(self):
        """Test case for get_sent_email_preview_ur_ls

        Get sent email URL for viewing in browser or downloading  # noqa: E501
        """
        pass

    def test_get_sent_email_tracking_pixels(self):
        """Test case for get_sent_email_tracking_pixels

        """
        pass

    def test_get_sent_emails(self):
        """Test case for get_sent_emails

        Get all sent emails in paginated form  # noqa: E501
        """
        pass

    def test_get_sent_emails_with_queue_results(self):
        """Test case for get_sent_emails_with_queue_results

        Get results of email sent with queues in paginated form  # noqa: E501
        """
        pass

    def test_get_sent_organization_emails(self):
        """Test case for get_sent_organization_emails

        """
        pass

    def test_wait_for_delivery_statuses(self):
        """Test case for wait_for_delivery_statuses

        """
        pass


if __name__ == '__main__':
    unittest.main()
